@@ -43,10 +43,11 @@ class EvalMetric:
         self.max_candidate = max_candidate
 
     def add_record(self, input, predicted, target, task='default'):
+        input = input.strip()
         if "[SEP]" in target:
-            target = target.split("[SEP]")
+            target = [t.strip() for t in target.split("[SEP]")]
         else:
-            target = [target]
+            target = [target.strip()]
 
         targets = []
         for pos in range(self.max_candidate):
@@ -72,15 +73,19 @@ class EvalMetric:
                 total = 0
                 f1 = 0
                 for pos, predict in enumerate(task['predicted']):
-                    target = task['target'][pos]
-                    equal = False
-                    if _normalize_answer(predict) == _normalize_answer(target):
-                        equal = True
-                    if equal:
-                        em += 1
-                        f1 += 1
-                    else:
-                        f1 += _f1_score(predict, target)
+                    em_list = [0]
+                    f1_list = [0]
+                    for target in task['targets'][pos]:
+                        equal = False
+                        if _normalize_answer(predict) == _normalize_answer(target):
+                            equal = True
+                        if equal:
+                            em_list.append(1)
+                            f1_list.append(1)
+                        else:
+                            f1_list.append(_f1_score(predict, target))
+                    em += max(em_list)
+                    f1 += max(f1_list)
                     total += 1
                 result = {"EM": em / total, "F1": f1 / total}
             if "nlg" in metric:
@@ -88,7 +93,7 @@ class EvalMetric:
                     from nlgeval import NLGEval
                 except ImportError:
                     print("nlg-eval package not install, plz install it from https://github.com/Maluuba/nlg-eval")
-
+                    raise
                 nlgeval = NLGEval(no_skipthoughts=True, no_glove=True, metrics_to_omit=["METEOR"])
                 result = nlgeval.compute_metrics(ref_list=list(map(list, zip(*task['targets']))),  # transpose
                                                  hyp_list=task['predicted'])
